package model

import (
	"time"
	"xorm.io/xorm"
)

type LuckyDrawRotaryTableSetting struct {
	Id                   int       `json:"id" xorm:"not null pk autoincr INT(11)"`
	IsOpen               int       `json:"is_open" xorm:"not null default 0 comment('0关1开') TINYINT(1)"`
	StartTime            time.Time `json:"start_time" xorm:"comment('活动开始时间') DATETIME"`
	EndTime              time.Time `json:"end_time" xorm:"comment('活动结束时间') DATETIME"`
	Condition            string    `json:"condition" xorm:"comment('抽奖条件') TEXT"`
	ChanceCondition      string    `json:"chance_condition" xorm:"comment('获得抽奖机会条件') TEXT"`
	ChanceRule           string    `json:"chance_rule" xorm:"comment('获得抽奖机会条件') TEXT"`
	AdBroadcast          int       `json:"ad_broadcast" xorm:"not null default 0 comment('广告轮播：0关闭1开启') TINYINT(1)"`
	AdBroadcastType      int       `json:"ad_broadcast_type" xorm:"not null default 0 comment('广告轮播数据：1仅真实数据2仅虚拟数据3两者读取') TINYINT(1)"`
	DrawTimesLimit       int       `json:"draw_times_limit" xorm:"not null default 0 comment('总抽奖机会次数限制，0不限制1限制') TINYINT(1)"`
	DrawTimes            int       `json:"draw_times" xorm:"not null default 0 comment('每人最多多少次抽奖次数') INT(11)"`
	DrawTimesByDay       int       `json:"draw_times_by_day" xorm:"not null default 0 comment('每人每日最多抽奖次数') INT(11)"`
	BingoTimes           int       `json:"bingo_times" xorm:"not null default 0 comment('每人最多中奖数') INT(11)"`
	BingoTimesByDay      int       `json:"bingo_times_by_day" xorm:"not null comment('每人每日最多中奖数') INT(11)"`
	MaxAwardNum          int       `json:"max_award_num" xorm:"not null default 8 comment('最多可以设置多少个奖品') INT(11)"`
	CreateTime           time.Time `json:"create_time" xorm:"created not null default 'CURRENT_TIMESTAMP' comment('创建时间') DATETIME"`
	UpdateTime           time.Time `json:"update_time" xorm:"updated not null default 'CURRENT_TIMESTAMP' comment('更新时间') DATETIME"`
	Pvd                  int       `json:"pvd" xorm:"not null default 1 comment('基数来源（1当前活动抽奖积分；2订单）') TINYINT(1)"`
	IsAutoIssueReward    int       `json:"is_auto_issue_reward" xorm:"not null default 1 comment('自动发放奖励，0否1是') TINYINT(1)"`
	BingoTimesByDayLimit int       `json:"bingo_times_by_day_limit" xorm:"not null default 0 comment('每天中奖奖机会次数限制，0不限制1限制') TINYINT(1)"`
}

func (setting *LuckyDrawRotaryTableSetting) init(engine *xorm.Engine) error {
	setting.Condition = "[]"
	setting.ChanceCondition = "[]"
	setting.AdBroadcastType = 1
	setting.BingoTimesByDay = 0
	setting.Pvd = 1
	setting.IsAutoIssueReward = 1
	setting.MaxAwardNum = 8
	_, err := engine.Insert(setting)
	return err
}

// Get
// @Description: 此方法会获取到一条唯一的基础设置信息，如果数据库没有会初始化生成一条信息
// @receiver setting
// @param engine
// @return error
func (setting *LuckyDrawRotaryTableSetting) Get(engine *xorm.Engine) error {
	exist, err := engine.IsTableExist(setting)
	if err != nil {
		return err
	}
	if !exist {
		if err := engine.CreateTables(setting); err != nil {
			return err
		}
	}
	if err != nil {
		return err
	}
	get, err := engine.Get(setting)
	if err != nil {
		return err
	}
	if !get {
		err := setting.init(engine)
		if err != nil {
			return err
		}
	}
	return nil
}

func (setting *LuckyDrawRotaryTableSetting) Update(engine *xorm.Engine, cols []string) error {
	if len(cols) == 0 {
		_, err := engine.ID(setting.Id).AllCols().Update(setting)
		if err != nil {
			return err
		}
		return nil
	} else {
		_, err := engine.ID(setting.Id).Cols(cols...).Update(setting)
		if err != nil {
			return err
		}
		return nil
	}
}
